library(R2WinBUGS)
library(BRugs)
library(brglm)

setwd("path")

datafinal <- read.table("finaldata.txt",sep=",",header=TRUE)

ser.br<-brglm(SP.cat~dayssd+ongedierte+reiniging2,data=datafinal,family=binomial)
summary(ser.br) 

modelsep <- function(){
			for( i in 1 : Nsub ) {
				y[i] ~ dbern(p[i])
				logit(p[i]) <- int + b1*x1[i] + b2*x2[i] + b3*x3[i] + b[clus[i]]
			}
			int ~ dt(0,0.2,1)
			b1 ~ dt(0,0.4,1)
			b2 ~ dt(0,0.4,1)
			b3 ~ dt(0,0.4,1)
			# Choice of priors for random effects variance
			for (i in 1:Nclust)
				{
					b[i] ~ dnorm(0,sb)
				}
			sb ~ dgamma(0.01,0.01)
			sigb <- 1/sb
			oint <- int-0.95*b1-b2*0.01-0.94*b3
			ob1 <- b1
			ob2 <- b2/2
			ob3 <- b3
		}

modelsep <- function(){
			for( i in 1 : Nsub ) {
				y[i] ~ dbern(p[i])
				logit(p[i]) <- int + b1*x1[i] + b2*x2[i] + b3*x3[i] + b[clus[i]]
				}
			int ~ dnorm(0.0,1.0E-6)
			b1 ~ dnorm(0.0,1.0E-6)
			b2 ~ dnorm(0.0,1.0E-6)
			b3 ~ dt(mpl,spl,1)
			# Choice of priors for random effects variance
			for (i in 1:Nclust){
					b[i] ~ dnorm(0,sb)
					}
			sb ~ dgamma(0.01,0.01)
			sigb <-  pow(sb, -1)
			}

datafinal$farm<-as.numeric(as.factor(datafinal$BESLNR))
names(datafinal)

t.r<-t.o<-list()
v.i<-matrix(0,83,3)
for (i in 1:83){
data.i<-datafinal[datafinal$farm==i,]
v.i[i,]<-c(i,unique(data.i$ongedierte),unique(data.i$reiniging2))
t.r[[i]]<-table(data.i$SP.cat,data.i$reiniging2)/dim(data.i)[1]
t.o[[i]]<-table(data.i$SP.cat,data.i$ongedierte)/dim(data.i)[1]
}

table(v.i[,3])

t.r1<-t.r2<-rep(0,83)
for (k in 1:83) {
t.r1[k]<-t.r[[k]][1]
if (!is.na(t.r[[k]][2])) {t.r2[k]<-t.r[[k]][2] }
}

t.o1<-t.o2<-rep(0,83)
for (k in 1:83) {
t.o1[k]<-t.o[[k]][1]
if (!is.na(t.o[[k]][2])) {t.o2[k]<-t.o[[k]][2] }
}

set.seed(923456)
ind.s<-c(c(1:83)[v.i[,2]==0][c(2,4)],sample(c(1:83)[v.i[,3]==0],4))

set.seed(23456)
id.farm.t<-sample(c(1:83)[(v.i[,2]!=0) & (v.i[,3]!=0)],54)
id.farm.c<-c(ind.s,id.farm.t)
datatrain<-datafinal[is.element(datafinal$farm,id.farm.c),]
datatest<-datafinal[!is.element(datafinal$farm,id.farm.c),]

ser.tr<-brglm(SP.cat~dayssd+ongedierte+reiniging2,data=datatrain,family=binomial)
summary(ser.tr)

ser.tt<-brglm(SP.cat~dayssd+ongedierte+reiniging2,data=datatest,family=binomial)
summary(ser.tt) 

dataused<-datatest
Nsub<-as.numeric(dim(dataused)[1])
Nclust<-as.numeric(length(unique(dataused$farm)))

int1<-summary(ser.tr)$coefficients[1,1]
b11<-summary(ser.tr)$coefficients[2,1]
b21<-summary(ser.tr)$coefficients[3,1]
b31<-summary(ser.tr)$coefficients[4,1]
bp<-rep(0,Nclust)
initssep<-function(){list(int=int1,b1=b11,b2=b21,b3=b31,b=bp,sb=1)
			   list(int=int1-.1,b1=b11-.1,b2=b21-.1,b3=b31-.1,b=bp,sb=2)}


y<-dataused$SP.cat
x1<-dataused$dayssd
x2<-dataused$ongedierte
x3<-dataused$reiniging2
clus<-as.numeric(as.factor(dataused$farm))
mpl<-summary(ser.tr)$coefficients[4,1]
spl<-1/(2*(summary(ser.tr)$coefficients[4,2])^2)

data <- list("y","x1","x2","x3","clus","Nsub","Nclust","mpl","spl")

#y<-dataused$SP.cat
#x1<-dataused$x1t
#x2<-dataused$x2t
#x3<-dataused$x3t
#data <- list("y","x1","x2","x3","clus","Nsub","Nclust")

parameters<-list("int","b1","b2","b3","sigb")
#parameters<-list("oint","ob1","ob2","ob3","sigb")

date()
set.seed(12345)
bfitnew<-BRugsFit(modelFile=modelsept,inits=initssep,data=data,numChains=2,parametersToSave=parameters,nThin=10,nBurnin=40000,nIter=400000,DIC=TRUE)
date()

date()
set.seed(12345)
bfitnewp<-BRugsFit(modelFile=modelsep,inits=initssep,data=data,numChains=2,parametersToSave=parameters,nThin=10,nBurnin=40000,nIter=400000,DIC=TRUE)
date()


